@@ -1,6 +1,7 @@
-//! # aliri_oauth2
+//! JWT authorization based on validating OAuth2 scopes
 //!
-//! JWT authorization based on validating OAuth2 scopes.
+//! This module uses the definition of OAuth2 as defined in
+//! [RFC 6749](https://datatracker.ietf.org/doc/html/rfc6749).
 
 #![warn(
     missing_docs,
@@ -17,9 +18,9 @@
 )]
 
 mod authority;
+pub mod oauth2;
 mod policy;
-mod scope;
 
 pub use authority::{Authority, AuthorityError};
-pub use policy::{InsufficientScopes, ScopesPolicy};
-pub use scope::{HasScopes, JustScope, Scope, ScopeRef, Scopes};
+pub use oauth2::Scope;
+pub use policy::{InsufficientScope, ScopePolicy};
